'use strict';

var _require = require('fetch-ponyfill')(),
    fetch = _require.fetch;

var _require2 = require('query-string'),
    stringify = _require2.stringify;

var _require3 = require('luxon'),
    DateTime = _require3.DateTime;

var isString = require('lodash/isString');
var isDate = require('lodash/isDate');

var createISODate = function createISODate(_ref) {
	var day = _ref.day,
	    time = _ref.time;
	return DateTime.fromFormat(day + ' ' + time, 'yyyyMMdd HHmmss', { zone: 'Asia/Seoul' }).toISO();
};

var createStopover = function createStopover(s) {
	var arrival = null;
	if (s.h_arv_tm !== '999999') {
		arrival = createISODate({ day: s.h_arv_dt, time: s.h_arv_tm });
	}
	var departure = null;
	if (s.h_dpt_tm !== '999999') {
		departure = createISODate({ day: s.h_dpt_dt, time: s.h_dpt_tm });
	}

	return {
		type: 'stopover',
		stop: {
			type: 'station',
			id: s.h_stop_rs_stn_cd + '',
			name: s.h_stop_rs_stn_nm
		},
		arrival: arrival,
		departure: departure
		// todo: h_act_arv_dlay_tnum
	};
};

var journeyLeg = async function journeyLeg(lineId, departureDate) {
	if (!isString(lineId) || lineId.length === 0) throw new Error('invalid or missing `lineId`, must be string');

	if (!isDate(departureDate)) throw new Error('`departureDate` must be a JS Date() object');
	var day = DateTime.fromJSDate(departureDate, { zone: 'Asia/Seoul' }).toFormat('yyyyMMdd');

	var endpoint = 'https://smart.letskorail.com/classes/com.korail.mobile.trainsInfo.TrainSchedule';
	var query = stringify({
		Device: 'IP',
		// Sid: '1QihOasC3e4vT2ld1RRiMw==',
		// Version: '180314001',
		srtCheckYn: 'Y',
		txtRunDt: day,
		txtTrnNo: lineId
	});
	var url = endpoint + '?' + query;
	var results = await fetch(url, { method: 'POST' });
	results = await results.json();

	if (results.strResult !== 'SUCC') throw new Error(JSON.stringify(results));
	return results.time_infos.time_info.map(createStopover);
};

module.exports = journeyLeg;